# noqa: INP001
# ozi/scripts/create_subproject_symlink.py
# Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
# See LICENSE.txt for license information.
# SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
# /// script
# requires-python = ">=3.10"
# dependencies = [
# 'pathvalidate~=3.2',
# ]
# ///
""":pep:`723` script: create symbolic link to subproject

Side-effects
^^^^^^^^^^^^

* Create symbolic link :file:`{MESON_BUILD_ROOT}/subprojects/ozi` to the
  versioned OZI wrap directory.

Environment Variables
^^^^^^^^^^^^^^^^^^^^^

* :envvar:`MESON_BUILD_ROOT`


"""
import os
import pathlib
import sys
from contextlib import suppress
from glob import glob

from pathvalidate import validate_filepath

if __name__ == '__main__':
    if sys.platform == 'win32':
        source = pathlib.Path(os.environ.get('MESON_BUILD_ROOT'))
    else:
        source = pathlib.Path(
            os.path.relpath(
                os.path.join('/', os.environ.get('MESON_BUILD_ROOT', os.path.relpath('..'))),
                '/',
            ),
        )
    validate_filepath(source)
    try:
        target = pathlib.Path(glob('subprojects/OZI-*', root_dir='/' / source)[0])
    except IndexError:
        print('OZI subproject directory not found', file=sys.stderr)
        exit(0)
    with suppress(FileExistsError):
        ('/' / source / 'subprojects' / 'ozi').symlink_to(
            '/' / source / target,
            target_is_directory=True,
        )



# noqa: INP001
# ozi/scripts/replace_ruff_target_version.py
# Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
# See LICENSE.txt for license information.
# SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
# /// script
# requires-python = ">=3.10"\
# dependencies = ['pathvalidate~=3.2',]
# ///
""":pep:`723` script: replace commented target-version in [tool.ruff].

Side-effects
^^^^^^^^^^^^

* in :file:`{MESON_BUILD_ROOT}/pyproject.toml` uncomment ``tool.ruff:target-version = ...``

Environment Variables
^^^^^^^^^^^^^^^^^^^^^

* :envvar:`MESON_BUILD_ROOT`

``pyproject.toml`` Tool Table Variables
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

* ``tool.ruff:target-version``

"""
import os
import sys
from pathlib import Path

from pathvalidate import validate_filepath

if __name__ == '__main__':
    if sys.platform == 'win32':
        build = Path(os.environ.get('MESON_BUILD_ROOT'))
    else:
        build = '/' / Path(
            os.path.relpath(
                Path('/', os.environ.get('MESON_BUILD_ROOT', Path('..').relative_to('.'))),
                '/',
            ),
        )
    validate_filepath(build, platform='auto')
    file = build / 'pyproject.toml'
    file.write_text(file.read_text().replace('# target-version', 'target-version'))



# noqa: INP001
# ozi/scripts/core_metadata_template.py
# Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
# See LICENSE.txt for license information.
# SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
# /// script
# requires-python = ">=3.10"
# dependencies = [
# 'tomli>=2;python_version<="3.11"',
# 'pathvalidate~=3.2',
# ]
# ///
""":pep:`723` script template: check OZI core dependency metadata

Input
^^^^^

#. Key name to match in ``project:optional_dependencies`` table

Output
^^^^^^

* String representation of matched value(s) for a key.

Environment Variables
^^^^^^^^^^^^^^^^^^^^^

* :envvar:`MESON_SOURCE_ROOT`

``pyproject.toml`` Project Variables
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

* ``project:optional_dependencies``

"""
import os
import pathlib
import sys

from pathvalidate import validate_filepath

if sys.version_info >= (3, 11):  # pragma: no cover
    import tomllib as toml
elif sys.version_info < (3, 11):  # pragma: no cover
    import tomli as toml

if __name__ == '__main__':
    # pylint: disable=consider-using-with
    if sys.platform == 'win32':
        source = pathlib.Path(os.environ.get('MESON_SOURCE_ROOT'))
    else:
        source = pathlib.Path(
            os.path.relpath(
                os.path.join(
                    '/', os.environ.get('MESON_SOURCE_ROOT', os.path.relpath('..'))
                ),
                '/',
            ),
        )
    validate_filepath(source, platform='auto')
    with open(source / 'pyproject.toml', 'rb') as fp:
        pyproject_toml = toml.load(fp)
    core_metadata = pyproject_toml.get('project', {'optional_dependencies': {}})
    print(core_metadata.get('optional_dependencies', {'todo': []}).get('@0@', 'fail'))
